---
title: cache
type: processor
status: stable
categories: ["Integration"]
---

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the contents of:
     lib/processor/cache.go
-->

import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';


Performs operations against a [cache resource](/docs/components/caches/about) for each message, allowing you to store or retrieve data within message payloads.


<Tabs defaultValue="common" values={[
  { label: 'Common', value: 'common', },
  { label: 'Advanced', value: 'advanced', },
]}>

<TabItem value="common">

```yml
# Common config fields, showing default values
label: ""
cache:
  resource: ""
  operator: ""
  key: ""
  value: ""
```

</TabItem>
<TabItem value="advanced">

```yml
# All config fields, showing default values
label: ""
cache:
  resource: ""
  operator: ""
  key: ""
  value: ""
  ttl: ""
```

</TabItem>
</Tabs>

For use cases where you wish to cache the result of processors consider using the [`cached` processor](/docs/components/processors/cached) instead.

This processor will interpolate functions within the `key` and `value` fields individually for each message. This allows you to specify dynamic keys and values based on the contents of the message payloads and metadata. You can find a list of functions [here](/docs/configuration/interpolation#bloblang-queries).

## Examples

<Tabs defaultValue="Deduplication" values={[
{ label: 'Deduplication', value: 'Deduplication', },
{ label: 'Deduplication Batch-Wide', value: 'Deduplication Batch-Wide', },
{ label: 'Hydration', value: 'Hydration', },
]}>

<TabItem value="Deduplication">


Deduplication can be done using the add operator with a key extracted from the
message payload, since it fails when a key already exists we can remove the
duplicates using a
[`bloblang` processor](/docs/components/processors/bloblang):

```yaml
pipeline:
  processors:
    - cache:
        resource: foocache
        operator: add
        key: '${! json("message.id") }'
        value: "storeme"
    - bloblang: root = if errored() { deleted() }

cache_resources:
  - label: foocache
    redis:
      url: tcp://TODO:6379
```

</TabItem>
<TabItem value="Deduplication Batch-Wide">


Sometimes it's necessary to deduplicate a batch of messages (AKA a window) by a single identifying value. This can be done by introducing a [`branch` processor](/docs/components/processors/branch), which executes the cache only once on behalf of the batch, in this case with a value make from a field extracted from the first and last messages of the batch:

```yaml
pipeline:
  processors:
    # Try and add one message to a cache that identifies the whole batch
    - branch:
        request_map: |
          root = if batch_index() == 0 {
            json("id").from(0) + json("meta.tail_id").from(-1)
          } else { deleted() }
        processors:
          - cache:
              operator: add
              key: ${! content() }
              value: t
    # Delete all messages if we failed
    - bloblang: |
        root = if errored().from(0) {
          deleted()
        }
```

</TabItem>
<TabItem value="Hydration">


It's possible to enrich payloads with content previously stored in a cache by
using the [`branch`](/docs/components/processors/branch) processor:

```yaml
pipeline:
  processors:
    - branch:
        processors:
          - cache:
              resource: foocache
              operator: get
              key: '${! json("message.document_id") }'
        result_map: 'root.message.document = this'

        # NOTE: If the data stored in the cache is not valid JSON then use
        # something like this instead:
        # result_map: 'root.message.document = content().string()'

cache_resources:
  - label: foocache
    memcached:
      addresses: [ "TODO:11211" ]
```

</TabItem>
</Tabs>

## Fields

### `resource`

The [`cache` resource](/docs/components/caches/about) to target with this processor.


Type: `string`  
Default: `""`  

### `operator`

The [operation](#operators) to perform with the cache.


Type: `string`  
Default: `""`  
Options: `set`, `add`, `get`, `delete`.

### `key`

A key to use with the cache.
This field supports [interpolation functions](/docs/configuration/interpolation#bloblang-queries).


Type: `string`  
Default: `""`  

### `value`

A value to use with the cache (when applicable).
This field supports [interpolation functions](/docs/configuration/interpolation#bloblang-queries).


Type: `string`  
Default: `""`  

### `ttl`

The TTL of each individual item as a duration string. After this period an item will be eligible for removal during the next compaction. Not all caches support per-key TTLs, those that do will have a configuration field `default_ttl`, and those that do not will fall back to their generally configured TTL setting.
This field supports [interpolation functions](/docs/configuration/interpolation#bloblang-queries).


Type: `string`  
Default: `""`  
Requires version 3.33.0 or newer  

```yml
# Examples

ttl: 60s

ttl: 5m

ttl: 36h
```

## Operators

### `set`

Set a key in the cache to a value. If the key already exists the contents are
overridden.

### `add`

Set a key in the cache to a value. If the key already exists the action fails
with a 'key already exists' error, which can be detected with
[processor error handling](/docs/configuration/error_handling).

### `get`

Retrieve the contents of a cached key and replace the original message payload
with the result. If the key does not exist the action fails with an error, which
can be detected with [processor error handling](/docs/configuration/error_handling).

### `delete`

Delete a key and its contents from the cache.  If the key does not exist the
action is a no-op and will not fail with an error.

