---
title: redis
type: processor
status: stable
categories: ["Integration"]
---

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the contents of:
     lib/processor/redis.go
-->

import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

Performs actions against Redis that aren't possible using a [`cache`](/docs/components/processors/cache) processor. Actions are
performed for each message and the message contents are replaced with the result. In order to merge the result into the original message compose this processor within a [`branch` processor](/docs/components/processors/branch).


<Tabs defaultValue="common" values={[
  { label: 'Common', value: 'common', },
  { label: 'Advanced', value: 'advanced', },
]}>

<TabItem value="common">

```yml
# Common config fields, showing default values
label: ""
redis:
  url: ""
  command: ""
  args_mapping: ""
```

</TabItem>
<TabItem value="advanced">

```yml
# All config fields, showing default values
label: ""
redis:
  url: ""
  kind: simple
  master: ""
  tls:
    enabled: false
    skip_cert_verify: false
    enable_renegotiation: false
    root_cas: ""
    root_cas_file: ""
    client_certs: []
  command: ""
  args_mapping: ""
  retries: 3
  retry_period: 500ms
```

</TabItem>
</Tabs>

## Examples

<Tabs defaultValue="Querying Cardinality" values={[
{ label: 'Querying Cardinality', value: 'Querying Cardinality', },
{ label: 'Running Total', value: 'Running Total', },
]}>

<TabItem value="Querying Cardinality">

If given payloads containing a metadata field `set_key` it's possible to query and store the cardinality of the set for each message using a [`branch` processor](/docs/components/processors/branch) in order to augment rather than replace the message contents:

```yaml
pipeline:
  processors:
    - branch:
        processors:
          - redis:
              url: TODO
              command: scard
              args_mapping: 'root = [ meta("set_key") ]'
        result_map: 'root.cardinality = this'
```

</TabItem>
<TabItem value="Running Total">

If we have JSON data containing number of friends visited during covid 19:

```json
{"name":"ash","month":"feb","year":2019,"friends_visited":10}
{"name":"ash","month":"apr","year":2019,"friends_visited":-2}
{"name":"bob","month":"feb","year":2019,"friends_visited":3}
{"name":"bob","month":"apr","year":2019,"friends_visited":1}
```

We can add a field that contains the running total number of friends visited:

```json
{"name":"ash","month":"feb","year":2019,"friends_visited":10,"total":10}
{"name":"ash","month":"apr","year":2019,"friends_visited":-2,"total":8}
{"name":"bob","month":"feb","year":2019,"friends_visited":3,"total":3}
{"name":"bob","month":"apr","year":2019,"friends_visited":1,"total":4}
```

Using the `incrby` command:

```yaml
pipeline:
  processors:
    - branch:
        processors:
          - redis:
              url: TODO
              command: incrby
              args_mapping: 'root = [ this.name, this.friends_visited ]'
        result_map: 'root.total = this'
```

</TabItem>
</Tabs>

## Fields

### `url`

The URL of the target Redis server. Database is optional and is supplied as the URL path.


Type: `string`  

```yml
# Examples

url: :6397

url: localhost:6397

url: redis://localhost:6379

url: redis://:foopassword@redisplace:6379

url: redis://localhost:6379/1

url: redis://localhost:6379/1,redis://localhost:6380/1
```

### `kind`

Specifies a simple, cluster-aware, or failover-aware redis client.


Type: `string`  
Default: `"simple"`  
Options: `simple`, `cluster`, `failover`.

### `master`

Name of the redis master when `kind` is `failover`


Type: `string`  
Default: `""`  

```yml
# Examples

master: mymaster
```

### `tls`

Custom TLS settings can be used to override system defaults.

**Troubleshooting**

Some cloud hosted instances of Redis (such as Azure Cache) might need some hand holding in order to establish stable connections. Unfortunately, it is often the case that TLS issues will manifest as generic error messages such as "i/o timeout". If you're using TLS and are seeing connectivity problems consider setting `enable_renegotiation` to `true`, and ensuring that the server supports at least TLS version 1.2.


Type: `object`  

### `tls.enabled`

Whether custom TLS settings are enabled.


Type: `bool`  
Default: `false`  

### `tls.skip_cert_verify`

Whether to skip server side certificate verification.


Type: `bool`  
Default: `false`  

### `tls.enable_renegotiation`

Whether to allow the remote server to repeatedly request renegotiation. Enable this option if you're seeing the error message `local error: tls: no renegotiation`.


Type: `bool`  
Default: `false`  
Requires version 3.45.0 or newer  

### `tls.root_cas`

An optional root certificate authority to use. This is a string, representing a certificate chain from the parent trusted root certificate, to possible intermediate signing certificates, to the host certificate.


Type: `string`  
Default: `""`  

```yml
# Examples

root_cas: |-
  -----BEGIN CERTIFICATE-----
  ...
  -----END CERTIFICATE-----
```

### `tls.root_cas_file`

An optional path of a root certificate authority file to use. This is a file, often with a .pem extension, containing a certificate chain from the parent trusted root certificate, to possible intermediate signing certificates, to the host certificate.


Type: `string`  
Default: `""`  

```yml
# Examples

root_cas_file: ./root_cas.pem
```

### `tls.client_certs`

A list of client certificates to use. For each certificate either the fields `cert` and `key`, or `cert_file` and `key_file` should be specified, but not both.


Type: `array`  

```yml
# Examples

client_certs:
  - cert: foo
    key: bar

client_certs:
  - cert_file: ./example.pem
    key_file: ./example.key
```

### `tls.client_certs[].cert`

A plain text certificate to use.


Type: `string`  
Default: `""`  

### `tls.client_certs[].key`

A plain text certificate key to use.


Type: `string`  
Default: `""`  

### `tls.client_certs[].cert_file`

The path of a certificate to use.


Type: `string`  
Default: `""`  

### `tls.client_certs[].key_file`

The path of a certificate key to use.


Type: `string`  
Default: `""`  

### `tls.client_certs[].password`

A plain text password for when the private key is a password encrypted PEM block according to RFC 1423. Warning: Since it does not authenticate the ciphertext, it is vulnerable to padding oracle attacks that can let an attacker recover the plaintext.


Type: `string`  
Default: `""`  

```yml
# Examples

password: foo

password: ${KEY_PASSWORD}
```

### `command`

The command to execute.
This field supports [interpolation functions](/docs/configuration/interpolation#bloblang-queries).


Type: `string`  
Default: `""`  
Requires version 4.3.0 or newer  

```yml
# Examples

command: scard

command: incrby

command: ${! meta("command") }
```

### `args_mapping`

A [Bloblang mapping](/docs/guides/bloblang/about) which should evaluate to an array of values matching in size to the number of arguments required for the specified Redis command.


Type: `string`  
Default: `""`  
Requires version 4.3.0 or newer  

```yml
# Examples

args_mapping: root = [ this.key ]

args_mapping: root = [ meta("kafka_key"), this.count ]
```

### `retries`

The maximum number of retries before abandoning a request.


Type: `int`  
Default: `3`  

### `retry_period`

The time to wait before consecutive retry attempts.


Type: `int`  
Default: `"500ms"`  


